@@ -271,6 +271,8 @@ def find_corpus_dataset(name):
 def generate_data_format(cls):
     if cls in (str, int, float, bytes):
         return f'<span class="kwd">{cls.__name__}</span>'
+    if cls == type(None):
+        return f'<span class="kwd">None</span>'
     elif isinstance(cls, typing._GenericAlias):
         args = []
         for arg in cls.__args__:
@@ -280,6 +282,8 @@ def generate_data_format(cls):
                 args.append(generate_data_format(arg))
         if cls._name in ('Tuple', 'List', 'Dict'):
             return f'<span class="kwd">{cls._name}</span>[{",".join(args)}]'
+        if cls._name is None: # aka union
+            return f'<span class="kwd">Union</span>[{",".join(args)}]'
     elif tuple in cls.__bases__ and hasattr(cls, '_fields'):
         fields = []
         for i, field in enumerate(cls._fields):
