@@ -9,7 +9,7 @@ import ir_datasets
 from ir_datasets.indices import PickleLz4FullStore
 from ir_datasets.util import Cache, DownloadConfig, GzipExtract, Lazy, Migrator, TarExtractAll
 from ir_datasets.datasets.base import Dataset, YamlDocumentation, FilteredQueries, FilteredScoredDocs, FilteredQrels
-from ir_datasets.formats import TrecDocs, TsvQueries, TrecQrels, TrecScoredDocs, BaseDocs
+from ir_datasets.formats import TsvQueries, TrecQrels, TrecScoredDocs, BaseDocs
 from ir_datasets.datasets.msmarco_passage import DUA, QRELS_DEFS, DL_HARD_QIDS_BYFOLD, DL_HARD_QIDS
 from ir_datasets.datasets.msmarco_document import TREC_DL_QRELS_DEFS
 
@@ -76,6 +76,8 @@ class MsMarcoV2Docs(BaseDocs):
             lookup_field=field,
             index_fields=['doc_id'],
             key_field_prefix='msmarco_doc_', # cut down on storage by removing prefix in lookup structure
+            size_hint=66500029281,
+            count_hint=11959635,
         )
         # return MsMArcoV2DocStore(self)
 
