@@ -2,6 +2,7 @@ from .base import GenericDoc, GenericQuery, GenericQrel, GenericScoredDoc, Gener
 from .base import BaseDocs, BaseQueries, BaseQrels, BaseScoredDocs, BaseDocPairs
 from .csv_fmt import CsvDocs, CsvQueries, CsvDocPairs
 from .tsv import TsvDocs, TsvQueries, TsvDocPairs
-from .trec import TrecDocs, TrecQueries, TrecXmlQueries, TrecColonQueries, TrecQrels, TrecPrels, TrecScoredDocs, TrecDoc, TrecQuery, TrecSubtopic, TrecQrel, TrecPrel
+from .trec import TrecDocs, TrecQueries, TrecXmlQueries, TrecColonQueries, TrecQrels, TrecPrels, TrecScoredDocs, TrecDoc, TitleUrlTextDoc, TrecQuery, TrecSubtopic, TrecQrel, TrecPrel
 from .webarc import WarcDocs, WarcDoc
 from .ntcir import NtcirQrels
+from .clirmatrix import CLIRMatrixQueries, CLIRMatrixQrels
